gmtime

Function gmtime 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn gmtime(timer: *const time_t) -> *mut tm
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/gmtime.html.

Safety

The caller is required to ensure that:

  • timer is a valid pointer
  • the function has exclusive access to the static tm structure it returns. This includes avoiding simultaneous calls to this function as well as to localtime().