localtime_r

Function localtime_r 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn localtime_r( timer: *const time_t, result: *mut tm, ) -> *mut tm
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/localtime.html.

Safety

The caller is required to ensure that:

  • timer is a valid pointer
  • result is convertible to an Out<tm>
  • the variables daylight, timezone and tzname are not accessed by user code for the duration of the call.