tzset

Function tzset 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tzset()
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/tzset.html.

Safety

The caller must ensure that daylight, timezone and tzname are not accessed by user code for the duration of the call.