the function has exclusive access to the static tm structure it
returns. This implies avoiding simultaneous calls to this function as
well as to gmtime()
the variables daylight, timezone and tzname are not accessed
by user code for the duration of the call.